# Disables freetype 1 and 2 bytecode interpreter.  Setting to 0 enables
# the bytecode interpreter in both freetype 1 and 2.
%define without_bytecode_interpreter    0

%define with_freetype1	1

%define ft1 freetype-pre1.4

%{!?with_xfree86:%define with_xfree86 1}

Distribution:   CCux
Packager:	Christian Wasem <wasem@cux-linux.de>

Name:		freetype
Version:	2.4.2
Release:	1
Epoch: 		1
License:	BSD/GPL dual license
URL:		http://www.freetype.org/
Group:		System/Libraries
BuildRoot:	%{_tmppath}/%{name}-buildroot
BuildArch:	i686
Summary:	A free and portable TrueType font rendering engine.
Source:  freetype-%{version}.tar.bz2
Source1: freetype-doc-%{version}.tar.bz2
Source2: ft2demos-%{version}.tar.bz2
Source3: %{ft1}.tar.bz2

# Fix build of freetype-1.4 with gcc 3.3
Patch3: freetype-1.4-ac25.patch
Patch4: freetype-1.4-gcc33.patch
# Add -lm when linking X demos
Patch5: ft2demos-2.1.9-mathlib.patch
Patch20:  freetype-2.1.10-enable-ft2-bci.patch
Patch21:  freetype-1.4-disable-ft1-bci.patch

# CVS bug fixes, mostly for embolding
Patch40:  freetype-2.1.10-cvsfixes.patch
# put back internal API, used by xorg 
Patch41:  freetype-2.1.10-xorgfix.patch
# fix autofit render setup
Patch42:  freetype-2.1.10-fixautofit.patch
# fix memleak
Patch43:  freetype-2.1.10-memleak.patch
# fix kerning wrongly disabled
Patch44:  freetype-2.1.10-fixkerning.patch
# fix bad anti-aliasing 
Patch45:  freetype-2.1.10-fixaliasing.patch

# Security fixes
Patch100: ft2-secu-fuzzed-ttf.patch

BuildRequires: automake autoconf libtool symlinks
BuildRequires: libX11-devel

#Automatically resolved build dependencies
BuildRequires: gettext-devel
BuildRequires: glibc-devel
BuildRequires: libICE-devel
BuildRequires: libSM-devel
BuildRequires: pkg-config
BuildRequires: zlib-devel

%description
The FreeType engine is a free and portable TrueType font rendering
engine, developed to provide TrueType support for a variety of
platforms and environments. FreeType is a library which can open and
manages font files as well as efficiently load, hint and render
individual glyphs. FreeType is not a font server or a complete
text-rendering library.

%if %{with_freetype1}
%package utils
Summary: 	A collection of FreeType utilities.
Group: 		System/Libraries
Requires: 	%{name} = %{epoch}:%{version}-%{release}

%description utils
The FreeType engine is a free and portable TrueType font rendering
engine, developed to provide TrueType support for a variety of
platforms and environments. FreeType is a library which can open and
manages font files as well as efficiently load, hint and render
individual glyphs. FreeType is not a font server or a complete
text-rendering library.
%endif

%package demos
Summary: 	A collection of FreeType demos.
Group: 		System/Libraries
Requires: 	%{name} = %{epoch}:%{version}-%{release}

%description demos
The FreeType engine is a free and portable TrueType font rendering
engine, developed to provide TrueType support for a variety of
platforms and environments. FreeType is a library which can open and
manages font files as well as efficiently load, hint and render
individual glyphs. FreeType is not a font server or a complete
text-rendering library.


%package devel
Summary: 	FreeType development libraries and header files
Group: 		Development/Libraries
Requires: 	%{name} = %{epoch}:%{version}-%{release}
Requires: 	zlib-devel

%description devel
The FreeType engine is a free and portable TrueType font rendering
engine, developed to provide TrueType support for a variety of
platforms and environments. FreeType is a library which can open and
manages font files as well as efficiently load, hint and render
individual glyphs. FreeType is not a font server or a complete
text-rendering library.

%prep
%setup -q -b 1 -a 2 -a 3

pushd src/truetype
#%patch100 -p0
popd

%if %{with_freetype1}
pushd %{ft1}
#%patch3   -p1 -b .ac25
%patch4   -p1 -b .gcc33

%if %{without_bytecode_interpreter}
#%patch21  -p1 -b .disable-ft1-bci
%endif
popd
%endif

pushd ft2demos-%{version}
#%patch5 -p1 -b .mathlib
popd

%if ! %{without_bytecode_interpreter}
#%patch20  -p1 -b .enable-ft2-bci
%endif

# Need to update libtool to get deplibs right for x86_64
#pushd builds/unix
#libtoolize --force
#aclocal
#autoconf
#popd

#pushd %{ft1}
#libtoolize --force
#aclocal
#autoconf
#popd

# Assorted fixes for 2.1.10 (thanks to Frederic Crozat)
#%patch40 -p1 -b .cvsfixes
#%patch41 -p1 -b .xorgfix
#%patch42 -p1 -b .fixautofit
#%patch43 -p1 -b .memleak
#%patch44 -p1 -b .fixkerning
#%patch45 -p1 -b .fixaliasing


%build
# Work around code generation problem with strict-aliasing
# https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=118021
#
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
export CXXFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"

# Build Freetype 2
{
  %configure
  make %{?_smp_mflags}
}

%if %{with_freetype1}
# Build Freetype 1.4
{
  pushd %{ft1}
  %configure --disable-debug --enable-static --enable-shared \
             --with-locale-dir=%{_datadir}/locale
  make

  # Absolute symlinks in the debug output break debuginfo, 
  # so use 'symlinks' to relativize and shorten; takes
  # two passes because 'symlinks' is stupid.
  symlinks -r -c . > /dev/null
  symlinks -r -s -c . > /dev/null

  popd
}
%endif

%if %{with_xfree86}
# Build freetype 2 demos
{
  pushd ft2demos-%{version}
  make TOP_DIR=".."
  popd
}
%endif

%install
rm -rf $RPM_BUILD_ROOT


# Install Freetype 2
%makeinstall gnulocaledir=$RPM_BUILD_ROOT%{_datadir}/locale

%if %{with_freetype1}
# Install Freetype 1
{
  pushd %{ft1}
  %makeinstall gnulocaledir=$RPM_BUILD_ROOT%{_datadir}/locale
  libtool --finish $RPM_BUILD_ROOT%{_libdir}
  popd
}
%endif
%if %{with_freetype1}
mkdir -p $RPM_BUILD_ROOT/%{_includedir}/freetype1
mv $RPM_BUILD_ROOT/%{_includedir}/freetype $RPM_BUILD_ROOT/%{_includedir}/freetype1
%endif

%if %{with_xfree86}
# Install freetype 2 demos
{
  for ftdemo in ftbench ftdiff ftdump ftgamma ftgrid ftlint ftmulti ftstring ftvalid ftview ;do
      install -m 755 ft2demos-%{version}/bin/$ftdemo $RPM_BUILD_ROOT/%{_bindir}
  done
}
%endif
%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%triggerpostun -- freetype < 2.0.5-3
{
  # ttmkfdir updated - as of 2.0.5-3, on upgrades we need xfs to regenerate
  # things to get the iso10646-1 encoding listed.
  for I in %{_datadir}/fonts/*/TrueType /usr/share/X11/fonts/TTF; do
      [ -d $I ] && [ -f $I/fonts.scale ] && [ -f $I/fonts.dir ] && touch $I/fonts.scale
  done
  exit 0
}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files -f %{name}.lang
%defattr(-,root,root)
%{_libdir}/libfreetype.so.*
%if %{with_freetype1}
%{_libdir}/libttf.so.*
%doc %{ft1}/README %{ft1}/announce docs
%endif
%{_locale}/*/LC_MESSAGES/freetype.mo

%if %{with_freetype1}
%files utils
%defattr(-,root,root)
# 2.0.4 version included in demos package now
#%{_bindir}/ftdump
# 2.0.4 version included in demos package now
#%{_bindir}/ftlint
%{_bindir}/fterror
%{_bindir}/ftmetric
%{_bindir}/ftsbit
%{_bindir}/ftstrpnm
%endif

%files demos
%defattr(-,root,root)
%{_bindir}/ftdump
%{_bindir}/ftlint
%if %{with_xfree86}
#%{_bindir}/ftmemchk
%{_bindir}/ftmulti
%{_bindir}/ftstring
#%{_bindir}/fttimer
%{_bindir}/ftview
%{_bindir}/ftbench
%{_bindir}/ftdiff
%{_bindir}/ftgamma
%{_bindir}/ftgrid
%{_bindir}/ftvalid
%endif

%files devel
%defattr(-,root,root)
%if %{with_freetype1}
%dir %{_includedir}/freetype1
%{_includedir}/freetype1/*
%endif
%dir %{_includedir}/freetype2
%{_includedir}/freetype2/*
%{_includedir}/ft2build.h
%if %{with_freetype1}
%{_libdir}/libttf.a
%{_libdir}/libttf.la
%{_libdir}/libttf.so
%endif
%{_libdir}/libfreetype.a
%{_libdir}/libfreetype.la
%{_libdir}/libfreetype.so
%{_bindir}/freetype-config
%{_pkgconfig}/freetype2.pc
%{_aclocal}/freetype2.m4
%{_docdir}/freetype-%{version}

%changelog
* Thu Aug 12 2010 Karsten Brockmann <arcam@ccux-linux.de> 2.4.2-1
- version update
* Sun Jul 18 2010 Karsten Brockmann <arcam@ccux-linux.de> 2.4.1-1
- version update
* Fri Jul 16 2010 Karsten Brockmann <arcam@ccux-linux.de> 2.4.0-1
- version update
* Sun May 13 2007 Karsten Brockmann <arcam@ccux-linux.de> 2.3.4-2
- added security fix against malicious TTF font files
* Sun May 13 2007 Karsten Brockmann <arcam@ccux-linux.de> 2.3.4-1
- Version update
* Wed Sep 20 2006 Karsten Brockmann <arcam@ccux-linux.de> 2.1.10-4
- rebuilt against gettext 1.5
* Sun Jul 02 2006 Christian Metzen <metzench@ccux-linux.de> 2.1.10-3
- step back temp. to 2.1.10 for xorg 7.1
* Thu May 18 2006 Christian Wasem <wasem@ccux-linux.de> 2.2.1-1
- Update to Version 2.2.1
* Tue Nov 29 2005 Christian Wasem <wasem@ccux-linux.de> 2.1.10-2
- rebuilt, removed wrong Obsoletes-Tag, moved more files to devel
* Mon Jun 13 2005 Christian Metzen <metzench@ccux-linux.de> 2.1.10-1
- Version update to 2.1.10, tweaked specfile, moved static files to devel package
* Fri Feb 11 2005 Christian Wasem <wasem@cux-linux.de> 2.1.9-3
- removing bytecode_interpreter-patch for better viewing results  
* Fri Feb 11 2005 Christian Wasem <wasem@cux-linux.de> 2.1.9-3
- specfile improvements  
* Thu Feb 10 2005 Christian Wasem <wasem@cux-linux.de> 2.1.9-1
- update from version 2.1.7-2
